@@ -1,30 +1,8 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2014  Aurélien Gâteau <agateau@kde.org>
+# SPDX-FileCopyrightText: 2014 Aurélien Gâteau <agateau@kde.org>
 #
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-#
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
-# IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
-# IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
-# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
-# NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
-# THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-# Python 2/3 compatibility (NB: we require at least 2.7)
-from __future__ import division, absolute_import, print_function, unicode_literals
+# SPDX-License-Identifier: BSD-2-Clause
 
 import argparse
 import logging
@@ -39,9 +17,9 @@ def parse_args(depdiagram_available):
     import textwrap
     parser = argparse.ArgumentParser(
         formatter_class=argparse.RawDescriptionHelpFormatter,
-        description=textwrap.dedent('''Generate API documentations of complex projects.
+        description=textwrap.dedent('''Generate API documentation of complex projects.
 
->> This function must be run from an empty directory (where the documentation will be build).''')
+>> This function must be run from an empty directory (where the documentation will be built).''')
         )
     group = add_sources_group(parser)
     group.add_argument('sourcesdir', type=normalized_path,
@@ -59,7 +37,7 @@ def parse_args(depdiagram_available):
     if args.depdiagram_dot_dir and not depdiagram_available:
         logging.error('You need to install the Graphviz Python bindings to '
                       'generate dependency diagrams.\n'
-                      'See <http://www.graphviz.org/Download.php>.')
+                      'See <https://www.graphviz.org/download/>.')
         exit(1)
 
     if not os.path.isdir(args.sourcesdir):
@@ -70,8 +48,10 @@ def parse_args(depdiagram_available):
 
 
 def add_sources_group(parser):
-    return parser.add_argument_group('sources')
-
+    group = parser.add_argument_group('sources')
+    group.add_argument('--accountsfile', type=normalized_path,
+            help='File with accounts information of SVN contributors.')
+    return group
 
 def add_output_group(parser):
     group = parser.add_argument_group('output options')
